@@ -14,9 +14,10 @@ register_worker({ phase => 'check', driver => 'direct' }, sub {
       and (not blessed $job->device or not $job->device->in_storage)) {
 
       config->{'snmp_try_slow_connect'} = false;
-      debug sprintf '[%s] skipping long SNMP timeouts for initial discover',
-        $job->device;
+      debug "running with fast SNMP timeouts for initial discover";
   }
+
+  debug "running with configured SNMP timeouts";
 });
 
 true;
